/**
 * @Config.java 22.10.2010
 * @author J&ouml;rg Czeschla
 *
 *         This file is a part of Sudoku Sudoku is free software; you can
 *         redistribute it and/or modify it under the terms of the GNU General
 *         Public License as published by the Free Software Foundation; either
 *         version 2 of the License, or (at your option) any later version.
 * 
 *         Sudoku is distributed in the hope that it will be useful, but WITHOUT
 *         ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 *         FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *         for more details.
 * 
 *         You should have received a copy of the GNU General Public License
 *         along with Spiele; if not, write to the Free Software Foundation,
 *         Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package de.yourwebs.sudoku;

import java.util.Calendar;
import java.util.GregorianCalendar;

/**
 * Constants of configuration data, paths and default values
 * 
 * @author J&ouml;rg Czeschla, <a href="https://javabeginners.de" target=
 *         "_blank">javabeginners.de</a>
 *
 */
public enum Config {
/**
 * The application's version number
 */
APP_VERSION("1.0.1"),
/**
 * The application's name
 */
APP_NAME("Sudoku"),
/**
 * The application's build number. It has to be changed each time, the
 * application's build is published
 */
BUILD("20231011-2"),
/**
 * The copyright of the application
 */
COPYRIGHT("(c) J&ouml;rg Czeschla - javabeginners.de, 2010-"
        + new GregorianCalendar().get(Calendar.YEAR)),
/**
 * Path to the application's icon
 */
ICON_PATH("img/sudoku_100.png"),
/**
 * Path to the icon shown at the success window when the game is finished
 */
SUCCESS_IMG("img/sudoku_heureka.png"),
/**
 * Path to the sound file's directory
 */
SOUND_PATH("de/yourwebs/sudoku/sound/"),
/**
 * Path to the sound file within the application
 */
SUCCESS_SOUND(SOUND_PATH.value + "applauselong.wav"),
/**
 * The absolute path to the configuration directory that contains the
 * configuration file
 */
CONFIG_DIR(System.getProperty("user.home")
        + System.getProperty("file.separator") + ".javabeginners"
        + System.getProperty("file.separator") + Config.APP_NAME.value),
/**
 * The absolute path to the file that stores the game's state when it's saved
 */
SAVE_FILE(CONFIG_DIR.value + "/stateFile"),
/**
 * The minimum difficulty of the game that can be chosen by the game's
 * difficulty slider. Must be greater than 0.
 */
MIN_DIFFICULTY("24"),
/**
 * The maximum difficulty of the game that can be chosen by the game's
 * difficulty slider. Must be lower than 81.
 */
MAX_DIFFICULTY("61");
/**
 * The enem's value
 */
public final String value;

/**
 * Constructor
 * @param s The value of the enum constant
 */
Config(final String s) {
    this.value = s;
}
}
