package de.yourwebs.sudoku;

import java.awt.Font;

import javax.swing.plaf.FontUIResource;

/**
 * The interface provides the constant settings of the game
 * 
 * @author J&ouml;rg Czeschla, <a href="https://javabeginners.de" target=
 *         "_blank">javabeginners.de</a>
 *
 */
public interface SudokuConstants {
    /**
     * Provides a black and white contrast if <code>true</code>
     */
    public static final boolean ACCESSIBILITY = false;
    /**
     * Shows a mistake hint if <code>true</code>. When a mistake is made by the
     * gamer, the row, column and square where the mistake occures are colored
     * for a time defined by {@link #MISTAKE_DELAY}..
     */
    public static final boolean MISTAKE_HINT = true;
    /**
     * Play an applause sound if <code>true</code> when the game is finished
     * successfully.
     */
    public static final boolean PLAY_SUCCESS_SOUND = false;
    /**
     * Play a sound calling the entered number if <code>true</code>.
     */
    public static final boolean PLAY_VOICE_OUTPUT = false;
    /**
     * The difficulty of the game showing the number of preset digits. The
     * difficulty is defined by omitting a variable number of digits from the
     * filled out game. The more digits are removed the more difficult the game
     * will be.
     */
    public static final int DIFFICULTY = 30;
    /**
     * Milliseconds the {@link #MISTAKE_HINT mistake hint} is shown
     */
    public static final int MISTAKE_DELAY = 1500;
    /**
     * Border length of the game's window
     */
    public static final int GUI_SIZE = 200;
    /**
     * The number's font weight.<br>
     * 0 means {@link java.awt.Font#PLAIN}<br>
     * 1 means {@link java.awt.Font#BOLD}.
     */
    public static final int FONT_WEIGHT = 0;
    /**
     * The game's font-size is calculated and adjusted by dividing
     * {@link de.yourwebs.sudoku.gui.SudokuGUI#faktor} by this constant. Must be
     * greater than 0.
     */
    public static final int FONT_SCALE = 7;
    /**
     * The font face of the game's numbers
     */
    public static final String FONT_FACE = "Verdana";
    /**
     * The tooltip font
     */
    public static final FontUIResource TOOLTIP_FONT = new FontUIResource(
            "Verdana", Font.PLAIN, 36);
}
