/*
 * @NumberTextField.java 29.12.2012 build: 29.12.2012 Copyright 2012
 * yourwebs.de. All rights reserved
 * 
 * @author J&ouml;rg Czeschla
 *
 * This file is a part of Sudoku Sudoku is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 * 
 * Sudoku is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * Sudoku; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307, USA.
 */
package de.yourwebs.sudoku.gui;

import javax.swing.JTextField;
import javax.swing.SwingConstants;

/**
 * An editable borderless TextField without highlighter that may only contain
 * numbers.
 * 
 * @author J&ouml;rg Czeschla, <a href="https://javabeginners.de" target=
 *         "_blank">javabeginners.de</a>
 *
 */
public class NumberTextField extends JTextField {

    /**
     * Constructs a text field of size 0
     */
    public NumberTextField() {
        this(0);
    }

    /**
     * Constructs a text field of the given size
     * 
     * @param size The size of the text field
     */
    public NumberTextField(final int size) {
        super(size);
        this.setHorizontalAlignment(SwingConstants.CENTER);
        this.setHighlighter(null);
        this.setBorder(null);
    }

    /**
     * Sets <code>txt</code> to the component only if it matches the regular
     * expression <code>[0-9]+</code>. If <code>txt</code> is
     * <code>null</code>or a white space charcter, the method returns. Otherwise
     * an empty String is set.
     */
    @Override
    public void setText(final String txt) {
        if (txt == null || txt.matches("\\s")) {
            return;
        }
        if (txt.matches("[0-9]+")) {
            super.setText(txt);
        } else {
            super.setText("");
        }
    }
}
