/*
 * @PrintablePanel.java 07.12.2010 build: 07.12.2010 Copyright 2010 yourwebs.de.
 * All rights reserved
 * 
 * @author J&ouml;rg Czeschla
 *
 * This file is a part of Sudoku Sudoku is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 * 
 * Sudoku is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * Sudoku; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307, USA.
 */
package de.yourwebs.sudoku.gui;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.LayoutManager;
import java.awt.print.PageFormat;
import java.awt.print.Printable;
import java.awt.print.PrinterException;

import javax.swing.JPanel;
import javax.swing.RepaintManager;

/**
 * A printable <code>JPanel</code> used as the main panel of the sudoku game.
 * 
 */
public class PrintablePanel extends JPanel implements Printable {

    /**
     * Constructs a panel with the given layout that can be printed
     * @param layout LayoutManager passed to this panel
     */
    public PrintablePanel(final LayoutManager layout) {
        super(layout);
    }

    /**
     * Prints the <code>JPanel</code> as an image. To fit on the page, it is
     * slightly scaled to 94%.
     */
    @Override
    public int print(final Graphics g, final PageFormat pageFormat,
            final int pageIndex) throws PrinterException {
        if (pageIndex > 0) {
            return (NO_SUCH_PAGE);
        }
        final Graphics2D g2d = (Graphics2D) g;
        final int x = (int) pageFormat.getImageableX() + 1;
        final int y = (int) pageFormat.getImageableY() + 1;
        g2d.translate(x, y);
        final RepaintManager currentManager = RepaintManager
                .currentManager(this);
        currentManager.setDoubleBufferingEnabled(false);
        // scale it a little bit to fit on the sheet
        g2d.scale(0.94, 0.94);
        this.paint(g2d);
        currentManager.setDoubleBufferingEnabled(true);
        return (PAGE_EXISTS);
    }
}
