package de.yourwebs.sudoku.gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.Graphics;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.net.URL;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;

import de.yourwebs.sudoku.Config;

/*
 * SuccessDialog.java 20.11.2010 Copyright 2010 yourwebs.de. All rights reserved
 * 
 * @author J&ouml;rg Czeschla
 *
 * This file is a part of Sudoku Sudoku is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 * 
 * Sudoku is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * Cent; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307, USA.
 */

/**
 * 
 * A dialog to be shown when the game is finished successfully.
 */
public class SuccessDialog extends JFrame implements ActionListener {
    /**
     * Button to create a new game
     */
    private JButton newButt;
    /**
     * Button that closes the dialog window
     */
    private JButton closeButt;
    /**
     * Button that closes the window and exits the game
     */
    private JButton exitButt;
    /**
     * the main frame
     */
    private final SudokuGUI gui;

    /**
     * Creates a dialog when the game is completed
     * 
     * @param gui
     *            The main frame
     */
    public SuccessDialog(final SudokuGUI gui) {
        super();
        this.gui = gui;
        this.setUndecorated(true);
        this.initGUI();
        this.pack();
        this.setAlwaysOnTop(true);
        this.setDefaultCloseOperation(EXIT_ON_CLOSE);
        this.setLocationRelativeTo(gui);
        this.setVisible(true);
    }

    /**
     * Create and initialize the gui
     */
    private void initGUI() {
        final JPanel contentPane = new JPanel() {

            private final Color bgColor = new Color(255, 255, 255, 0);

            @Override
            protected void paintComponent(final Graphics g) {
                g.setColor(bgColor);
                g.fillRect(0, 0, this.getWidth(), this.getHeight());
            }
        };
        contentPane.setLayout(new BorderLayout());
        final URL url = this.getClass().getClassLoader()
                .getResource(Config.ICON_PATH.value);
        final ImageIcon icon = new ImageIcon(url);
        contentPane.add(new JLabel(icon,
                SwingConstants.CENTER), BorderLayout.CENTER);

        final JPanel buttPanel = new JPanel(new FlowLayout());
        newButt = new JButton("Neues Spiel");
        newButt.addActionListener(this);
        buttPanel.add(newButt);
        closeButt = new JButton("Schlie\u00DFen");
        buttPanel.add(closeButt);
        closeButt.addActionListener(this);
        exitButt = new JButton("Beenden");
        buttPanel.add(exitButt);
        exitButt.addActionListener(this);
        contentPane.add(buttPanel, BorderLayout.SOUTH);
        this.setContentPane(contentPane);
    }

    @Override
    public void actionPerformed(final ActionEvent e) {
        if (e.getSource() == newButt) {
            gui.initNewSudoku();
            this.setVisible(false);
            this.dispose();
        }
        if (e.getSource() == closeButt) {
            this.setVisible(false);
            this.dispose();
        }
        if (e.getSource() == exitButt) {
            System.exit(0);
        }
    }
}
