/*
 * @SudokuMenu.java 20.11.2010 build: 20.11.2010 Copyright 2010 - 2013
 * yourwebs.de. All rights reserved
 * 
 * @author J&ouml;rg Czeschla
 *
 * This file is a part of Sudoku Sudoku is free software; you can redistribute
 * it and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 * 
 * Sudoku is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * Sudoku; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307, USA.
 */
package de.yourwebs.sudoku.gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;
import de.yourwebs.sudoku.Config;
import de.yourwebs.sudoku.SudokuEngine;

/**
 * Provides a menu bar
 * 
 */
public class SudokuMenu extends JMenuBar implements ActionListener {
    /**
     * Item to open a saved usually unfinished game
     */
    private JMenuItem openItem;
    /**
     * Item to save am game's state
     */
    private JMenuItem saveItem;
    /**
     * Item to exit the game without saving
     */
    private JMenuItem exitItem;
    /**
     * Item to initialize a new game
     */
    private JMenuItem newItem;
    /**
     * Item to print the actual game's panel
     */
    private JMenuItem printItem;
    /**
     * Item to complete the game panel
     */
    private JMenuItem completeItem;
    /**
     * Item to show a separate window displaying the solution of the game
     */
    private JMenuItem solutionItem;
    /**
     * Item to help the player by adding one digit at a random position of the
     * game's empty fields
     */
    private JMenuItem helpItem;
    /**
     * Item to show an {@link de.yourwebs.sudoku.gui.OptionDialog option dialog}
     */
    private JMenuItem optionsItem;
    /**
     * Item to show some information about the game
     */
    private JMenuItem aboutItem;
    /**
     * Reference to he main frame
     */
    SudokuGUI gui;
    /**
     * Reference to the game's core engine
     */
    SudokuEngine engine;

    /**
     * Creates the program's menu bar
     * 
     * @param gui
     *            The main frame
     */
    public SudokuMenu(final SudokuGUI gui) {
        this.gui = gui;
        this.engine = gui.getEngine();
        this.init();
    }

    /**
     * Creates and initializes the menu bar's ui
     */
    private void init() {
        // Datei-Menu
        final JMenu dateiMenu = new JMenu("Datei");
        this.add(dateiMenu);

        openItem = new JMenuItem("Laden");
        openItem.addActionListener(this);
        openItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_O, InputEvent.CTRL_DOWN_MASK));
        saveItem = new JMenuItem("Speichern");
        saveItem.addActionListener(this);
        saveItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_S, InputEvent.CTRL_DOWN_MASK));
        exitItem = new JMenuItem("Schlie\u00DFen");
        exitItem.addActionListener(this);
        exitItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_Q, InputEvent.CTRL_DOWN_MASK));
        newItem = new JMenuItem("Neu");
        newItem.addActionListener(this);
        newItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_N, InputEvent.CTRL_DOWN_MASK));
        printItem = new JMenuItem("Drucken");
        printItem.addActionListener(this);
        printItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_P, InputEvent.CTRL_DOWN_MASK));
        completeItem = new JMenuItem("Vervollst\u00e4ndigen");
        completeItem.addActionListener(this);
        completeItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_V, InputEvent.CTRL_DOWN_MASK));
        solutionItem = new JMenuItem("Aufl\u00F6sen");
        solutionItem.addActionListener(this);
        solutionItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_C, InputEvent.CTRL_DOWN_MASK));
        helpItem = new JMenuItem("Hilfe");
        helpItem.addActionListener(this);
        helpItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_H, InputEvent.CTRL_DOWN_MASK));

        dateiMenu.add(newItem);
        dateiMenu.add(openItem);
        dateiMenu.add(completeItem);
        dateiMenu.add(solutionItem);
        dateiMenu.add(helpItem);
        dateiMenu.addSeparator();
        dateiMenu.add(saveItem);
        dateiMenu.add(printItem);
        dateiMenu.addSeparator();
        dateiMenu.add(exitItem);

        // Extras-Menu
        final JMenu extrasMenu = new JMenu("Extras");
        this.add(extrasMenu);

        optionsItem = new JMenuItem("Einstellungen");
        optionsItem.addActionListener(this);
        optionsItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_E, InputEvent.CTRL_DOWN_MASK));

        extrasMenu.add(optionsItem);

        // Hilfe-Menu
        final JMenu helpMenu = new JMenu("Hilfe");
        this.add(helpMenu);

        aboutItem = new JMenuItem("\u00DCber " + Config.APP_NAME.value);
        aboutItem.addActionListener(this);
        aboutItem.setAccelerator(KeyStroke
                .getKeyStroke(KeyEvent.VK_A, InputEvent.CTRL_DOWN_MASK));

        helpMenu.add(aboutItem);
    }

    /*
     * Eventhandling der Menuleiste
     */
    @Override
    public void actionPerformed(final ActionEvent arg0) {
        if (arg0.getSource() == openItem) {
            gui.load();
        }
        if (arg0.getSource() == saveItem) {
            gui.save();
        }
        if (arg0.getSource() == exitItem) {
            System.exit(0);
        }
        if (arg0.getSource() == newItem) {
            gui.initNewSudoku();
        }
        if (arg0.getSource() == printItem) {
            gui.print();
        }
        if (arg0.getSource() == completeItem) {
            gui.updateSudoku(engine.getResultArray());
        }
        if (arg0.getSource() == solutionItem) {
            gui.showSolution();
        }
        if (arg0.getSource() == helpItem && !gui.getHintMode()) {
            gui.help();
        }
        if (arg0.getSource() == optionsItem) {
            new OptionDialog(gui);
        }
        if (arg0.getSource() == aboutItem) {
            new AboutDialog();
        }
    }
}
